@@ -1,7 +1,5 @@
-import inspect
-
 try:
-    # For python 3.8 and later
+    # For Python 3.8 and later
     import importlib.metadata as importlib_metadata
 except ImportError:
     # For everyone else
@@ -18,9 +16,6 @@ logger = logging.getLogger(__name__)
 
 def setup(app):
     version = importlib_metadata.version('sphinxcontrib-spelling')
-    # If we are running inside the test suite, "app" will be a module.
-    if inspect.ismodule(app):
-        return
     logger.info('Initializing Spelling Checker %s', version)
     app.add_builder(SpellingBuilder)
     # Register the 'spelling' directive for setting parameters within
@@ -33,14 +28,14 @@ def setup(app):
     app.add_config_value('spelling_show_suggestions', False, 'env')
     # Report the whole line that has the error
     app.add_config_value('spelling_show_whole_line', True, 'env')
+    # Emit misspelling as a sphinx warning instead of info message
+    app.add_config_value('spelling_warning', False, 'env')
     # Set the language for the text
     app.add_config_value('spelling_lang', 'en_US', 'env')
     # Set the language for the tokenizer
     app.add_config_value('tokenizer_lang', 'en_US', 'env')
     # Set a user-provided list of words known to be spelled properly
-    app.add_config_value('spelling_word_list_filename',
-                         None,
-                         'env')
+    app.add_config_value('spelling_word_list_filename', None, 'env')
     # Assume anything that looks like a PyPI package name is spelled properly
     app.add_config_value('spelling_ignore_pypi_package_names', False, 'env')
     # Assume words that look like wiki page names are spelled properly
@@ -58,9 +53,10 @@ def setup(app):
     # Add any user-defined filter classes
     app.add_config_value('spelling_filters', [], 'env')
     # Set a user-provided list of files to ignore
-    app.add_config_value('spelling_exclude_patterns',
-                         [],
-                         'env')
+    app.add_config_value('spelling_exclude_patterns', [], 'env')
+    # Choose whether or not the misspelled output should be displayed
+    # in the terminal
+    app.add_config_value('spelling_verbose', True, 'env')
     return {
         "parallel_read_safe": True,
         "parallel_write_safe": True,
