@@ -1,4 +1,3 @@
-# encoding: utf-8
 #
 # Copyright (c) 2010 Doug Hellmann.  All rights reserved.
 #
@@ -14,7 +13,7 @@ else:
     enchant_import_error = None
 
 
-class SpellingChecker(object):
+class SpellingChecker:
     """Checks the spelling of blocks of text.
 
     Uses options defined in the sphinx configuration file to control
@@ -31,7 +30,7 @@ class SpellingChecker(object):
         if filters is None:
             filters = []
         self.dictionary = enchant.DictWithPWL(lang, word_list_filename)
-        self.tokenizer = get_tokenizer(tokenizer_lang, filters)
+        self.tokenizer = get_tokenizer(tokenizer_lang, filters=filters)
         self.original_tokenizer = self.tokenizer
         self.suggest = suggest
         self.context_line = context_line
