@@ -1,4 +1,3 @@
-# encoding: utf-8
 #
 # Copyright (c) 2010 Doug Hellmann.  All rights reserved.
 #
@@ -23,7 +22,6 @@ class SpellingDirective(rst.Directive):
 
     """
 
-    option_spec = {}
     has_content = True
 
     def run(self):
