@@ -1,4 +1,3 @@
-# encoding: utf-8
 #
 # Copyright (c) 2010 Doug Hellmann.  All rights reserved.
 #
@@ -10,13 +9,11 @@
 import builtins
 import imp
 import subprocess
-import xmlrpc.client as xmlrpc_client
+from xmlrpc import client as xmlrpc_client
 
 from enchant.tokenize import Filter, get_tokenizer, tokenize, unit_tokenize
-
 from sphinx.util import logging
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -35,7 +32,7 @@ class AcronymFilter(Filter):
 class list_tokenize(tokenize):
 
     def __init__(self, words):
-        tokenize.__init__(self, '')
+        super().__init__('')
         self._words = words
 
     def next(self):
@@ -145,13 +142,13 @@ class IgnoreWordsFilter(Filter):
 
     def __init__(self, tokenizer, word_set):
         self.word_set = set(word_set)
-        Filter.__init__(self, tokenizer)
+        super().__init__(tokenizer)
 
     def _skip(self, word):
         return word in self.word_set
 
 
-class IgnoreWordsFilterFactory(object):
+class IgnoreWordsFilterFactory:
 
     def __init__(self, words):
         self.words = words
@@ -165,24 +162,21 @@ class PyPIFilterFactory(IgnoreWordsFilterFactory):
     """
     def __init__(self):
         client = xmlrpc_client.ServerProxy('https://pypi.python.org/pypi')
-        IgnoreWordsFilterFactory.__init__(self, client.list_packages())
+        super().__init__(client.list_packages())
 
 
 class PythonBuiltinsFilter(Filter):
     """Ignore names of built-in Python symbols.
     """
     def _skip(self, word):
-        try:
-            return hasattr(builtins, word)
-        except UnicodeEncodeError:
-            return False
+        return hasattr(builtins, word)
 
 
 class ImportableModuleFilter(Filter):
     """Ignore names of modules that we could import.
     """
     def __init__(self, tokenizer):
-        Filter.__init__(self, tokenizer)
+        super().__init__(tokenizer)
         self.found_modules = set()
         self.sought_modules = set()
 
@@ -191,20 +185,17 @@ class ImportableModuleFilter(Filter):
             self.sought_modules.add(word)
             try:
                 imp.find_module(word)
-            except UnicodeEncodeError:
-                return False
             except ImportError:
                 return False
-            else:
-                self.found_modules.add(word)
-                return True
+            self.found_modules.add(word)
+            return True
         return word in self.found_modules
 
 
 class ContributorFilter(IgnoreWordsFilter):
     """Accept information about contributors as spelled correctly.
 
-    Look in the git history for authors and commiters and accept
+    Look in the git history for authors and committers and accept
     tokens that are in the set.
     """
 
@@ -214,7 +205,7 @@ class ContributorFilter(IgnoreWordsFilter):
 
     def __init__(self, tokenizer):
         contributors = self._get_contributors()
-        IgnoreWordsFilter.__init__(self, tokenizer, contributors)
+        super().__init__(tokenizer, contributors)
 
     def _get_contributors(self):
         logger.info('Scanning contributors')
@@ -226,8 +217,8 @@ class ContributorFilter(IgnoreWordsFilter):
             p = subprocess.run(cmd, check=True, stdout=subprocess.PIPE)
         except subprocess.CalledProcessError as err:
             logger.warning('Called: {}'.format(' '.join(cmd)))
-            logger.warning('Failed to scan contributors: {}'.format(err))
+            logger.warning(f'Failed to scan contributors: {err}')
             return set()
         output = p.stdout.decode('utf-8')
         tokenizer = get_tokenizer('en_US', filters=[])
-        return set(word for word, pos in tokenizer(output))
+        return {word for word, pos in tokenizer(output)}
